# Korpuskulum

A package for evaluating particle distribution with respect to segmented membranes.

_Etymology: Corpuscle is an English word meaning a tiny particle, derived from the Latin "corpusculum"._


![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)
[![Building](https://github.com/rosalindfranklininstitute/korpuskulum/actions/workflows/python-package.yml/badge.svg)](https://github.com/rosalindfranklininstitute/korpuskulum/actions/workflows/python-package.yml)

## Installation

You can install the package by running the following commands:

```
pip install -e .
```

## Testing

You can run the package tests by running the following commands:

```
pip install .[test]
pytest
```

## Basic usage

You can run the package by using a combination of flags after the following command
```
korpus main
```
The flags and their respective usages can be displayed using the command
```
korpus main --help
```


## Issues

Please use the [GitHub issue tracker](https://github.com/rosalindfranklininstitute/korpuskulum/issues) to submit bugs or request features.

## Contributions

If you would like to help contribute to python-template, please read our [contribution](CONTRIBUTING.md) guide and [code of conduct](CODE_OF_CONDUCT.md).

## License

Copyright Rosalind Franklin Institute, 2024.

Distributed under the terms of the Apache-2.0 license, python-template is free and open source software.
